@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::JSONAPI;
-$Mojolicious::Plugin::JSONAPI::VERSION = '1.2';
+$Mojolicious::Plugin::JSONAPI::VERSION = '1.3';
 use Mojo::Base 'Mojolicious::Plugin';
 
 use JSONAPI::Document;
@@ -135,7 +135,7 @@ sub create_error_helpers {
         render_error => sub {
             my ( $c, $status, $errors, $data, $meta ) = @_;
 
-            unless ( defined($errors) && ref($errors) ne 'ARRAY' ) {
+            unless ( defined($errors) && ref($errors) eq 'ARRAY' ) {
                 $errors = [
                     {
                         status => $status || 500,
@@ -147,7 +147,7 @@ sub create_error_helpers {
             return $c->render(
                 status => $status || 500,
                 json => {
-                    $data ? $data : (),
+                    $data ? %$data : (),
                     $meta ? ( meta => $meta ) : (),
                     errors => $errors,
                 }
@@ -182,7 +182,7 @@ Mojolicious::Plugin::JSONAPI - Mojolicious Plugin for building JSON API complian
 
 =head1 VERSION
 
-version 1.2
+version 1.3
 
 =head1 SYNOPSIS
 
